==> openjdk-21_21.0.10~4ea.orig.tar.xz: openjdk-21-21.0.10~4ea/test/jdk/java/net/Authenticator/GetAuthenticatorTest.java <==
/*
 * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
import java.lang.ref.Reference;
import java.net.Authenticator;
import java.net.NetPermission;
import java.net.PasswordAuthentication;
import java.security.AccessControlException;

/**
 * @test
 * @bug 8169068
 * @summary  Basic test for Authenticator.getDefault()
 * @run main/othervm -Djava.security.manager=allow GetAuthenticatorTest
 */
public class GetAuthenticatorTest {

    static final class MyAuthenticator extends Authenticator {

        MyAuthenticator () {
            super ();
        }

        @Override
        public PasswordAuthentication getPasswordAuthentication () {
            System.out.println ("Auth called");
            return (new PasswordAuthentication ("user",
                        "passwordNotCheckedAnyway".toCharArray()));
        }

    }

    public static void main (String args[]) throws Exception {
        Authenticator defaultAuth = Authenticator.getDefault();
        if (defaultAuth != null) {
            throw new RuntimeException("Unexpected authenticator: null expected");
        }
        MyAuthenticator auth = new MyAuthenticator();
        Authenticator.setDefault(auth);
        defaultAuth = Authenticator.getDefault();
        if (defaultAuth != auth) {
            throw new RuntimeException("Unexpected authenticator: auth expected");
        }
        System.setSecurityManager(new SecurityManager());
        try {
            defaultAuth = Authenticator.getDefault();
            throw new RuntimeException("Expected security exception not raised");
        } catch (AccessControlException s) {
            System.out.println("Got expected exception: " + s);
            if (!s.getPermission().equals(new NetPermission("requestPasswordAuthentication"))) {
                throw new RuntimeException("Unexpected permission check: " + s.getPermission());
            }
        }
        System.out.println("Test passed with default authenticator "
                           + defaultAuth);
    }
}

==> openjdk-26_26~28ea.orig.tar.xz: openjdk-26-26~28ea/test/jdk/java/net/Authenticator/GetAuthenticatorTest.java <==
/*
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
import java.lang.ref.Reference;
import java.net.Authenticator;
import java.net.PasswordAuthentication;

/**
 * @test
 * @bug 8169068
 * @summary  Basic test for Authenticator.getDefault()
 * @run main/othervm GetAuthenticatorTest
 */
public class GetAuthenticatorTest {

    static final class MyAuthenticator extends Authenticator {

        MyAuthenticator () {
            super ();
        }

        @Override
        public PasswordAuthentication getPasswordAuthentication () {
            System.out.println ("Auth called");
            return (new PasswordAuthentication ("user",
                        "passwordNotCheckedAnyway".toCharArray()));
        }

    }

    public static void main (String args[]) throws Exception {
        Authenticator defaultAuth = Authenticator.getDefault();
        if (defaultAuth != null) {
            throw new RuntimeException("Unexpected authenticator: null expected");
        }
        MyAuthenticator auth = new MyAuthenticator();
        Authenticator.setDefault(auth);
        defaultAuth = Authenticator.getDefault();
        if (defaultAuth != auth) {
            throw new RuntimeException("Unexpected authenticator: auth expected");
        }
        System.out.println("Test passed with default authenticator "
                           + defaultAuth);
    }
}
